@@ -1,6 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id: uptime.c,v 1.7 1999/03/31 16:53:05 martin Exp $ */
+/* $Id: uptime.c,v 1.8 2003/10/19 16:10:39 carlos Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -21,30 +19,28 @@
    along with LibGTop; see the file COPYING. If not, write to the
    Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
- */
+*/
 
 #include <glibtop/uptime.h>
 
-const char *glibtop_names_uptime[GLIBTOP_MAX_UPTIME] =
+const char *glibtop_names_uptime [GLIBTOP_MAX_UPTIME] =
 {
-    "uptime", "idletime", "boot_time"
+	"uptime", "idletime"
 };
 
-const unsigned glibtop_types_uptime[GLIBTOP_MAX_UPTIME] =
+const unsigned glibtop_types_uptime [GLIBTOP_MAX_UPTIME] =
 {
-    GLIBTOP_TYPE_DOUBLE, GLIBTOP_TYPE_DOUBLE, GLIBTOP_TYPE_ULONG
+	GLIBTOP_TYPE_DOUBLE, GLIBTOP_TYPE_DOUBLE
 };
 
-const char *glibtop_labels_uptime[GLIBTOP_MAX_UPTIME] =
+const char *glibtop_labels_uptime [GLIBTOP_MAX_UPTIME] =
 {
-    N_ ("Uptime"),
-    N_ ("Idletime"),
-    N_ ("Boot time")
+	N_("Uptime"),
+	N_("Idletime")
 };
 
-const char *glibtop_descriptions_uptime[GLIBTOP_MAX_UPTIME] =
+const char *glibtop_descriptions_uptime [GLIBTOP_MAX_UPTIME] =
 {
-    N_ ("Time in seconds since system boot"),
-    N_ ("Time in seconds the system spent in the idle task since system boot"),
-    N_ ("Boot time (seconds sice epoch)")
+	N_("Time in seconds since system boot"),
+	N_("Time in seconds the system spent in the idle task since system boot")
 };
